%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

% Units are:
% P - kN | M - kNm | e - mm | Zb,Zt - mm3 | A - mm2

% ---------------------------------------------------
% Example 1 - Analysis of a simply supported section
% ---------------------------------------------------
% 1. Define the section properties in file "get_sec_props.m"
% 2. Define the prestress properties in file "get_ps_props.m"
% 3. Analyse the section:
%           ss_anal(span, npts, transfer udl, service udl)
[x Mt Ms] = ss_anal(8.0,20,2.4,11.9);
% 4. Find the critical moments (at midspan):
maxMt = max(Mt); maxMs  = max(Ms);
% 5. Determine an eccentricity:
Section_Design(x,Mt,Ms);
% 6. Examine the critical section stresses and the Magnel diagram:
section_check(maxMt,maxMs);

% ---------------------------------------------------
% Example 2 - Based on Example 7 of CBA:
% ---------------------------------------------------

% 1. Change the properties to those of Example 2 in
%   - "get_sec_props.m"
%   - "get_ps_props.m"

% 2. Perform the analysis of the 2-span beam
L = [6,8];
E = 30;
I = [100e8,100e8];
R = [-1,0,-1,0,-1,0];
LMg = [1,1,20,0,0;
       2,1,20,0,0];
LMq = [1,1,30,0,0;
       2,1,30,0,0];
LMp = [1,4,100,0,0;
       2,4,-100,8,0];

OutMat = CBA(L,E,I,R,LMp,'r');
LMt = addLM(LMg,LMp); % transfer moments
figure; 
OutMat_t = CBA(L,E,I,R,LMt,'r');
LMs = addLM(LMt,LMq); % service moments
figure; 
OutMat_s = CBA(L,E,I,R,LMs,'r');

% 3. Send it to the cable_zones function
cable_zones(OutMat_t, OutMat_s);

% Or try some more detailed design:
% 4. Extract bending moments
x = OutMat_t(:,1);
Mt = OutMat_t(:,2);
Ms = OutMat_s(:,2);

% 5. Do a section design check:
Section_Design(x,Mt,Ms);

% 6. And a stress check at a position z:
z = 6;  % m in from the left hand side
iSec = find(x >= z, 1);
Section_Design(x(iSec),Mt(iSec),Ms(iSec));