%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

function Section_Design(x,Mt,Ms)
% this program calulates the maximum and minimum cable eccentricities for a
% prestressed beam subjected to moment vector M, given a prestress, P.
% Units are:
% P - kN | M - kNm | e - mm | Zb,Zt - mm3 | A - mm2

    [P ec loss_t loss_s f_allow] = get_ps_props();
    [A Zt Zb I yt yb] = get_sec_props();
    L = x(length(x));
    
    pe = Magnel(max(Mt),max(Ms),1);
    Pdes = input('CHOOSE A DESIGN PRESTRESS (kN):');
    
    npts = length(x);
    for i = 1:npts
        pe = Magnel(Mt(i),Ms(i),0,Pdes);
        e(i,:) = -pe(5:6)+yb;
        Zmin(i,:) = MinZ(f_allow,Mt(i),Ms(i),loss_s); 
    end
    figure; 
    subplot(2,1,1);hold on;
    fill([0 L*1e3 L*1e3 0],[0 0 yt+yb yt+yb],'r');
    plot(x.*1e3,e,'k','linewidth',2);
    plot(x.*1e3,yb,'k--','linewidth',2);
    xlabel('Distance along member (mm)');
    ylabel('Distance from soffit (mm)');
    subplot(2,1,2);hold on;
    plot(x.*1e3,Zmin(:,1),'k','linewidth',2);
    plot(x.*1e3,-Zmin(:,2),'r','linewidth',2);
    plot([0 L*1e3], [Zt Zt], 'k--');
    plot([0 L*1e3], [-Zb -Zb], 'r--');
    xlabel('Distance along member (mm)');
    ylabel('Minimum Section Modulus (mm3)');    
end
            
