%
%    Copyright (C) 2008  Colin Caprani - www.colincaprani.com
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.

function [ft fb] = stress(P,e,M,A,Zt,Zb,plotflag,row)
% returns the top and bottom fibre stresses
% assumes compression positive
% Units are:
% P - kN | M - kNm | e - mm | Zb,Zt - mm3 | A - mm2

P = P*1e3; M = M*1e6;

fp = P/A;
fpeb = P*e/Zb; fpet = -P*e/Zt;
fmb = -M/Zb; fmt = M/Zt;

fb = fp + fpeb + fmb;
ft = fp + fpet + fmt;

if plotflag == 1
    x = 0; y = 100;
    row = 4*(row-1);
    subplot(2,4,row+1); fill([x fp fp x],[x x y y],'r'); 
    title('P/A'); xlabel('Stress'); ylabel('Depth %');
    subplot(2,4,row+2); fill([x fpeb fpet x],[x x y y],'r'); 
    title('Pe/Z'); xlabel('Stress');
    subplot(2,4,row+3); fill([x fmb fmt x],[x x y y],'r'); 
    title('M/Z'); xlabel('Stress');
    subplot(2,4,row+4); fill([x fb ft x],[x x y y],'r'); 
    title('Total'); xlabel('Stress');
end

